<?php
/**
 * Plugin Name:           GamiPress - WishList Member integration
 * Plugin URI:            https://wordpress.org/plugins/gamipress-wishlist-member-integration/
 * Description:           Connect GamiPress with WishList Member.
 * Version:               1.0.2
 * Author:                GamiPress
 * Author URI:            https://gamipress.com/
 * Text Domain:           gamipress-wishlist-member-integration
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          6.0
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               GamiPress\WishList_Member
 * @author                GamiPress
 * @copyright             Copyright (c) GamiPress
 */

final class GamiPress_WishList_Member {

    /**
     * @var         GamiPress_WishList_Member $instance The one true GamiPress_WishList_Member
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      GamiPress_WishList_Member self::$instance The one true GamiPress_WishList_Member
     */
    public static function instance() {

        if( !self::$instance ) {
            self::$instance = new GamiPress_WishList_Member();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'GAMIPRESS_WISHLIST_MEMBER_VER', '1.0.2' );

        // Plugin path
        define( 'GAMIPRESS_WISHLIST_MEMBER_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'GAMIPRESS_WISHLIST_MEMBER_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            require_once GAMIPRESS_WISHLIST_MEMBER_DIR . 'includes/admin.php';
            require_once GAMIPRESS_WISHLIST_MEMBER_DIR . 'includes/listeners.php';
            require_once GAMIPRESS_WISHLIST_MEMBER_DIR . 'includes/requirements.php';
            require_once GAMIPRESS_WISHLIST_MEMBER_DIR . 'includes/rules-engine.php';
            require_once GAMIPRESS_WISHLIST_MEMBER_DIR . 'includes/scripts.php';
            require_once GAMIPRESS_WISHLIST_MEMBER_DIR . 'includes/triggers.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {
        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'GAMIPRESS_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'GamiPress - WishList Member integration requires %s and %s in order to work. Please install and activate them.', 'gamipress-wishlist-member-integration' ),
                        '<a href="https://wordpress.org/plugins/gamipress/" target="_blank">GamiPress</a>',
                        '<a href="https://member.wishlistproducts.com/" target="_blank">WishList Member</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'GAMIPRESS_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'GamiPress' ) ) {
            return false;
        }

        // Requirements on multisite install
        if( is_multisite() && gamipress_is_network_wide_active() && is_main_site() ) {

            // On main site, need to check if integrated plugin is installed on any sub site to load all configuration files
            if( gamipress_is_plugin_active_on_network( 'wishlist-member/wpm.php' ) ) {
                return true;
            }

        }

        if ( ! class_exists( 'WishListMember3' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = GAMIPRESS_WISHLIST_MEMBER_DIR . '/languages/';
        $lang_dir = apply_filters( 'gamipress_wishlist_member_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'gamipress-wishlist-member-integration' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'gamipress-wishlist-member-integration', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/gamipress-wishlist-member-integration/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/gamipress-wishlist-member-integration/ folder
            load_textdomain( 'gamipress-wishlist-member-integration', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/gamipress-wishlist-member-integration/languages/ folder
            load_textdomain( 'gamipress-wishlist-member-integration', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'gamipress-wishlist-member-integration', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true GamiPress_WishList_Member instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \GamiPress_WishList_Member The one true GamiPress_WishList_Member
 */
function GamiPress_WishList_Member() {
    return GamiPress_WishList_Member::instance();
}
add_action( 'plugins_loaded', 'GamiPress_WishList_Member' );
